==> mall-center-api-0.0.4-sources.jar: cn/com/duiba/mall/center/api/domain/dto/seckill/SecKillActSkuConfDto.java <==
package cn.com.duiba.mall.center.api.domain.dto.seckill;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by HePeng on 2019/01/14 14:00.
 */
public class SecKillActSkuConfDto implements Serializable {
    private static final long serialVersionUID = 8135145578859295574L;
    /**
     * 配置id
     */
    private Long id;

    /**
     * 活动id
     */
    private Long actId;

    /**
     * 对应的sku id
     */
    private Long appSkuId;

    /**
     * 规格描述
     */
    private String specConf;

    /**
     * 原价需要钱（单位：分）
     */
    private Long price;

    /**
     * 原价需要积分
     */
    private Integer credits;

    /**
     * 秒杀需要钱（单位：分）
     */
    private Long secPrice;

    /**
     * 秒杀需要积分
     */
    private Integer secCredits;

    /**
     * 秒杀上限
     */
    private Integer secLimit;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getActId() {
        return actId;
    }

    public void setActId(Long actId) {
        this.actId = actId;
    }

    public Long getAppSkuId() {
        return appSkuId;
    }

    public void setAppSkuId(Long appSkuId) {
        this.appSkuId = appSkuId;
    }

    public String getSpecConf() {
        return specConf;
    }

    public void setSpecConf(String specConf) {
        this.specConf = specConf;
    }

    public Long getPrice() {
        return price;
    }

    public void setPrice(Long price) {
        this.price = price;
    }

    public Integer getCredits() {
        return credits;
    }

    public void setCredits(Integer credits) {
        this.credits = credits;
    }

    public Long getSecPrice() {
        return secPrice;
    }

    public void setSecPrice(Long secPrice) {
        this.secPrice = secPrice;
    }

    public Integer getSecCredits() {
        return secCredits;
    }

    public void setSecCredits(Integer secCredits) {
        this.secCredits = secCredits;
    }

    public Integer getSecLimit() {
        return secLimit;
    }

    public void setSecLimit(Integer secLimit) {
        this.secLimit = secLimit;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> mall-center-api-0.1.33-20251013.092126-2-sources.jar: cn/com/duiba/mall/center/api/domain/dto/seckill/SecKillActSkuConfDto.java <==
package cn.com.duiba.mall.center.api.domain.dto.seckill;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by HePeng on 2019/01/14 14:00.
 */
public class SecKillActSkuConfDto implements Serializable {
    private static final long serialVersionUID = 8135145578859295574L;
    /**
     * 配置id
     */
    private Long id;

    /**
     * 活动id
     */
    private Long actId;

    /**
     * 对应的sku id
     */
    private Long appSkuId;

    /**
     * 规格描述
     */
    private String specConf;

    /**
     * 原价需要钱（单位：分）
     */
    private Long price;

    /**
     * 原价需要积分
     */
    private Integer credits;

    /**
     * 划线价
     */
    private Long facePrice;

    /**
     * 秒杀需要钱（单位：分）
     */
    private Long secPrice;

    /**
     * 秒杀需要积分
     */
    private Integer secCredits;

    /**
     * 秒杀上限
     */
    private Integer secLimit;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getActId() {
        return actId;
    }

    public void setActId(Long actId) {
        this.actId = actId;
    }

    public Long getAppSkuId() {
        return appSkuId;
    }

    public void setAppSkuId(Long appSkuId) {
        this.appSkuId = appSkuId;
    }

    public String getSpecConf() {
        return specConf;
    }

    public void setSpecConf(String specConf) {
        this.specConf = specConf;
    }

    public Long getPrice() {
        return price;
    }

    public void setPrice(Long price) {
        this.price = price;
    }

    public Integer getCredits() {
        return credits;
    }

    public void setCredits(Integer credits) {
        this.credits = credits;
    }

    public Long getSecPrice() {
        return secPrice;
    }

    public void setSecPrice(Long secPrice) {
        this.secPrice = secPrice;
    }

    public Integer getSecCredits() {
        return secCredits;
    }

    public void setSecCredits(Integer secCredits) {
        this.secCredits = secCredits;
    }

    public Integer getSecLimit() {
        return secLimit;
    }

    public void setSecLimit(Integer secLimit) {
        this.secLimit = secLimit;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(Long facePrice) {
        this.facePrice = facePrice;
    }
}
